## `edge` Package

This `edge` package contains all the classes that supports:

- Edge typification and description
- Edges metadata
- Edges Perception Dimensions
- Signals

For details, each module in this package has 
Docstrings that helps to describe its purpose.
